@@ -75,7 +75,7 @@ const std::string messageStrings[MAX_MSG + 1] =
 class BSlizr_GUI : public BWidgets::Window
 {
 public:
-	BSlizr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeWindow parentWindow);
+	BSlizr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeView parentWindow);
 	~BSlizr_GUI ();
 	void portEvent (uint32_t port_index, uint32_t buffer_size, uint32_t format, const void *buffer);
 	void send_record_on ();
@@ -217,8 +217,8 @@ private:
 };
 
 
-BSlizr_GUI::BSlizr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeWindow parentWindow) :
-	Window (800, 560, "B.Slizr", parentWindow, true),
+BSlizr_GUI::BSlizr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeView parentWindow) :
+	Window (800, 560, "B.Slizr", parentWindow, true, PUGL_MODULE, 0),
 	controller (NULL), write_function (NULL),
 
 	mContainer (0, 0, 800, 560, "main"),
@@ -913,11 +913,11 @@ void BSlizr_GUI::redrawMainMonitor ()
 	monitorDisplay.update ();
 }
 
-LV2UI_Handle instantiate (const LV2UI_Descriptor *descriptor, const char *plugin_uri, const char *bundle_path,
+static LV2UI_Handle instantiate (const LV2UI_Descriptor *descriptor, const char *plugin_uri, const char *bundle_path,
 						  LV2UI_Write_Function write_function, LV2UI_Controller controller, LV2UI_Widget *widget,
 						  const LV2_Feature *const *features)
 {
-	PuglNativeWindow parentWindow = 0;
+	PuglNativeView parentWindow = 0;
 	LV2UI_Resize* resize = NULL;
 
 	if (strcmp(plugin_uri, BSLIZR_URI) != 0)
@@ -928,7 +928,7 @@ LV2UI_Handle instantiate (const LV2UI_Descriptor *descriptor, const char *plugin
 
 	for (int i = 0; features[i]; ++i)
 	{
-		if (!strcmp(features[i]->URI, LV2_UI__parent)) parentWindow = (PuglNativeWindow) features[i]->data;
+		if (!strcmp(features[i]->URI, LV2_UI__parent)) parentWindow = (PuglNativeView) features[i]->data;
 		else if (!strcmp(features[i]->URI, LV2_UI__resize)) resize = (LV2UI_Resize*)features[i]->data;
 	}
 	if (parentWindow == 0) std::cerr << "BSlizr.lv2#GUI: No parent window.\n";
@@ -963,35 +963,47 @@ LV2UI_Handle instantiate (const LV2UI_Descriptor *descriptor, const char *plugin
 	return (LV2UI_Handle) ui;
 }
 
-void cleanup(LV2UI_Handle ui)
+static void cleanup(LV2UI_Handle ui)
 {
 	BSlizr_GUI* pluginGui = (BSlizr_GUI*) ui;
-	delete pluginGui;
+	if (pluginGui) delete pluginGui;
 }
 
-void portEvent(LV2UI_Handle ui, uint32_t port_index, uint32_t buffer_size,
+static void portEvent(LV2UI_Handle ui, uint32_t port_index, uint32_t buffer_size,
 	uint32_t format, const void* buffer)
 {
 	BSlizr_GUI* pluginGui = (BSlizr_GUI*) ui;
-	pluginGui->portEvent(port_index, buffer_size, format, buffer);
+	if (pluginGui) pluginGui->portEvent(port_index, buffer_size, format, buffer);
 }
 
 static int callIdle (LV2UI_Handle ui)
 {
 	BSlizr_GUI* pluginGui = (BSlizr_GUI*) ui;
-	pluginGui->handleEvents ();
+	if (pluginGui) pluginGui->handleEvents ();
 	return 0;
 }
 
-static const LV2UI_Idle_Interface idle = { callIdle };
+static int callResize (LV2UI_Handle ui, int width, int height)
+{
+	BSlizr_GUI* self = (BSlizr_GUI*) ui;
+	if (!self) return 0;
+	
+	BEvents::ExposeEvent* ev = new BEvents::ExposeEvent (self, self, BEvents::CONFIGURE_REQUEST_EVENT, self->getPosition().x, self->getPosition().y, width, height);
+	self->addEventToQueue (ev);
+	return 0;
+}
+
+static const LV2UI_Idle_Interface idle = {callIdle};
+static const LV2UI_Resize resize = {nullptr, callResize};
 
 static const void* extensionData(const char* uri)
 {
 	if (!strcmp(uri, LV2_UI__idleInterface)) return &idle;
+	else if(!strcmp(uri, LV2_UI__resize)) return &resize;
 	else return NULL;
 }
 
-const LV2UI_Descriptor guiDescriptor = {
+static const LV2UI_Descriptor guiDescriptor = {
 		BSLIZR_GUI_URI,
 		instantiate,
 		cleanup,
